@@ -50,29 +50,18 @@ def check_value_free(result, func, cargs):
         msg = 'Error in "%s": %s' % (func.__name__, rt.Error_GetLastErrorMsg() )
         rt.Error_Reset()
         raise RTreeError(msg)
-    retval = ctypes.string_at(result)[:]
-    free(result)
-    return retval
+    return result
 
 def free_returned_char_p(result, func, cargs):
-
     size = ctypes.c_int()
     retvalue = ctypes.string_at(result)
-    free(result)
+    #free(result)
     return retvalue
     
     
 
-try:
-    from numpy import array, ndarray
-    HAS_NUMPY = True
-except ImportError:
-    HAS_NUMPY = False
-
 if os.name == 'nt':
-    # stolen from Shapely
-    # http://trac.gispython.org/projects/PCL/browser/Shapely/trunk/shapely/geos.py
-    lib_name = 'libsidx.dll'
+    lib_name = 'spatialindex1_c.dll'
     try:
         local_dlls = os.path.abspath(os.__file__ + "../../../DLLs")
         original_path = os.environ['PATH']
@@ -85,14 +74,13 @@ if os.name == 'nt':
                 pass
     except (ImportError, WindowsError):
         raise
-
-
 elif os.name == 'posix':
     platform = os.uname()[0]
-    lib_name = 'libsidx.so'
+    lib_name = 'libspatialindex_c.so'
     if platform == 'Darwin':
+        lib_name = 'libspatialindex_c.dylib'
         free = ctypes.CDLL(find_library('libc')).free
-    else:        
+    else:
         free = ctypes.CDLL(find_library('libc.so.6')).free
     rt = ctypes.CDLL(lib_name)
 else:
@@ -118,7 +106,7 @@ NEXTFUNC = ctypes.CFUNCTYPE(ctypes.c_int,
                             ctypes.POINTER(ctypes.POINTER(ctypes.c_double)),
                             ctypes.POINTER(ctypes.c_uint32),
                             ctypes.POINTER(ctypes.POINTER(ctypes.c_ubyte)),
-                            ctypes.POINTER(ctypes.c_size_t))
+                            ctypes.POINTER(ctypes.c_uint32))
 
 rt.Index_CreateWithStream.argtypes = [ctypes.c_void_p, NEXTFUNC] 
 rt.Index_CreateWithStream.restype = ctypes.c_void_p
@@ -146,7 +134,7 @@ rt.Index_InsertData.argtypes = [ctypes.c_void_p,
                                 ctypes.POINTER(ctypes.c_double), 
                                 ctypes.c_uint32, 
                                 ctypes.POINTER(ctypes.c_ubyte), 
-                                ctypes.c_size_t]
+                                ctypes.c_uint32]
 rt.Index_InsertData.restype = ctypes.c_int
 rt.Index_InsertData.errcheck = check_return
 
@@ -166,7 +154,7 @@ rt.Index_Intersects_obj.argtypes = [ctypes.c_void_p,
                                     ctypes.POINTER(ctypes.c_double), 
                                     ctypes.c_uint32, 
                                     ctypes.POINTER(ctypes.POINTER(ctypes.c_void_p)),
-                                    ctypes.POINTER(ctypes.c_uint32)]
+                                    ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_Intersects_obj.restype = ctypes.c_int
 rt.Index_Intersects_obj.errcheck = check_return
 
@@ -175,16 +163,22 @@ rt.Index_Intersects_id.argtypes = [ctypes.c_void_p,
                                     ctypes.POINTER(ctypes.c_double), 
                                     ctypes.c_uint32, 
                                     ctypes.POINTER(ctypes.POINTER(ctypes.c_uint64)),
-                                    ctypes.POINTER(ctypes.c_uint32)]
+                                    ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_Intersects_id.restype = ctypes.c_int
 rt.Index_Intersects_id.errcheck = check_return
 
+rt.Index_Intersects_count.argtypes = [  ctypes.c_void_p,
+                                        ctypes.POINTER(ctypes.c_double),
+                                        ctypes.POINTER(ctypes.c_double),
+                                        ctypes.c_uint32,
+                                        ctypes.POINTER(ctypes.c_uint64)]
+
 rt.Index_NearestNeighbors_obj.argtypes = [  ctypes.c_void_p,
                                             ctypes.POINTER(ctypes.c_double), 
                                             ctypes.POINTER(ctypes.c_double), 
                                             ctypes.c_uint32, 
                                             ctypes.POINTER(ctypes.POINTER(ctypes.c_void_p)),
-                                            ctypes.POINTER(ctypes.c_uint32)]
+                                            ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_NearestNeighbors_obj.restype = ctypes.c_int
 rt.Index_NearestNeighbors_obj.errcheck = check_return
 
@@ -193,10 +187,21 @@ rt.Index_NearestNeighbors_id.argtypes = [  ctypes.c_void_p,
                                             ctypes.POINTER(ctypes.c_double), 
                                             ctypes.c_uint32, 
                                             ctypes.POINTER(ctypes.POINTER(ctypes.c_uint64)),
-                                            ctypes.POINTER(ctypes.c_uint32)]
+                                            ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_NearestNeighbors_id.restype = ctypes.c_int
 rt.Index_NearestNeighbors_id.errcheck = check_return
 
+rt.Index_GetLeaves.argtypes = [ ctypes.c_void_p,
+                                ctypes.POINTER(ctypes.c_uint32), 
+                                ctypes.POINTER(ctypes.POINTER(ctypes.c_uint32)), 
+                                ctypes.POINTER(ctypes.POINTER(ctypes.c_int64)), 
+                                ctypes.POINTER(ctypes.POINTER(ctypes.POINTER(ctypes.c_int64))),
+                                ctypes.POINTER(ctypes.POINTER(ctypes.POINTER(ctypes.c_double))),
+                                ctypes.POINTER(ctypes.POINTER(ctypes.POINTER(ctypes.c_double))),
+                                ctypes.POINTER(ctypes.c_uint32)]
+rt.Index_GetLeaves.restype = ctypes.c_int
+rt.Index_GetLeaves.errcheck = check_return
+
 rt.Index_DestroyObjResults.argtypes = [ctypes.POINTER(ctypes.POINTER(ctypes.c_void_p)), ctypes.c_uint32]
 rt.Index_DestroyObjResults.restype = None
 rt.Index_DestroyObjResults.errcheck = check_void_done
@@ -398,21 +403,24 @@ rt.IndexProperty_SetFileName.restype = ctypes.c_int
 rt.IndexProperty_SetFileName.errcheck = check_return
 
 rt.IndexProperty_GetFileName.argtypes = [ctypes.c_void_p]
-rt.IndexProperty_GetFileName.errcheck = check_value_free
+rt.IndexProperty_GetFileName.errcheck = free_returned_char_p
+rt.IndexProperty_GetFileName.restype = ctypes.POINTER(ctypes.c_char)
 
 rt.IndexProperty_SetFileNameExtensionDat.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 rt.IndexProperty_SetFileNameExtensionDat.restype = ctypes.c_int
 rt.IndexProperty_SetFileNameExtensionDat.errcheck = check_return
 
 rt.IndexProperty_GetFileNameExtensionDat.argtypes = [ctypes.c_void_p]
-rt.IndexProperty_GetFileNameExtensionDat.errcheck = check_value_free
+rt.IndexProperty_GetFileNameExtensionDat.errcheck = free_returned_char_p
+rt.IndexProperty_GetFileNameExtensionDat.restype = ctypes.POINTER(ctypes.c_char)
 
 rt.IndexProperty_SetFileNameExtensionIdx.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 rt.IndexProperty_SetFileNameExtensionIdx.restype = ctypes.c_int
 rt.IndexProperty_SetFileNameExtensionIdx.errcheck = check_return
 
 rt.IndexProperty_GetFileNameExtensionIdx.argtypes = [ctypes.c_void_p]
-rt.IndexProperty_GetFileNameExtensionIdx.errcheck = check_value_free
+rt.IndexProperty_GetFileNameExtensionIdx.errcheck = free_returned_char_p
+rt.IndexProperty_GetFileNameExtensionIdx.restype = ctypes.POINTER(ctypes.c_char)
 
 rt.IndexProperty_SetIndexID.argtypes = [ctypes.c_void_p, ctypes.c_int64]
 rt.IndexProperty_SetIndexID.restype = ctypes.c_int
@@ -423,4 +431,4 @@ rt.IndexProperty_GetIndexID.restype = ctypes.c_int64
 rt.IndexProperty_GetIndexID.errcheck = check_value
 
 rt.SIDX_Version.restype = ctypes.POINTER(ctypes.c_char)
-rt.SIDX_Version.errcheck = free_returned_char_p
\ No newline at end of file
+rt.SIDX_Version.errcheck = free_returned_char_p
